exceptiontools.UnboundedTimeIntervalError
=========================================

.. inheritance-diagram:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
